Learn R Programming

compindexR (version 0.1.3)

si_linear_exc_vif: Calculate Si using linear method by excluding Xi using VIF

Description

Calculate Si using linear method by excluding Xi using VIF

Usage

si_linear_exc_vif(x, avg_type = "simple", vif_threshold = 4.5)

Value

A data frame

Arguments

x

A Dataframe

avg_type

Choosing average type. So far "simple", "geometric" and "harmonic" average are availableç

vif_threshold

Threshold for VIF. Based on this threshold variables from input data (x) are excluded for the calculations.

Examples

Run this code
x <- data.frame(rnorm(20),rnorm(20),rnorm(20),rnorm(20))
si_linear_exc_vif(x,avg_type = "simple", vif_threshold = 4.5)

Run the code above in your browser using DataLab