powered by
Calculate Si using linear method by excluding Xi using VIF
si_linear_exc_vif(x, avg_type = "simple", vif_threshold = 4.5)
A data frame
A Dataframe
Choosing average type. So far "simple", "geometric" and "harmonic" average are availableç
Threshold for VIF. Based on this threshold variables from input data (x) are excluded for the calculations.
x <- data.frame(rnorm(20),rnorm(20),rnorm(20),rnorm(20)) si_linear_exc_vif(x,avg_type = "simple", vif_threshold = 4.5)
Run the code above in your browser using DataLab